@@ -3,9 +3,9 @@ from rest_framework import serializers
 from dcim.api.nested_serializers import NestedPlatformSerializer
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer, NestedMountedVolumeSerializer, NestedDeviceSerializer
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationLinuxVolume, \
-    LinuxDevice, TemplateConfigurationLinuxVolume
+    NestedMountedVolumeSerializer, NestedDeviceSerializer
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationDrive, \
+    LinuxDevice, TemplateConfigurationDrive
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -97,12 +97,12 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
         )
 
 
-class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
+class StorageConfigurationDriveSerializer(serializers.ModelSerializer):
     linux_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = StorageConfigurationLinuxVolume
+        model = StorageConfigurationDrive
         fields = (
             "id",
             "device",
@@ -113,12 +113,12 @@ class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
         )
 
 
-class TemplateConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
+class TemplateConfigurationDriveSerializer(serializers.ModelSerializer):
     drive = NestedDriveSerializer(required=False, allow_null=True)
     platform = NestedPlatformSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = TemplateConfigurationLinuxVolume
+        model = TemplateConfigurationDrive
         fields = (
             "id",
             "platform",
