@@ -6,6 +6,7 @@ from netbox_storage.api.views import (
     FilesystemViewSet,
     PartitionViewSet,
     MountedVolumeViewSet,
+    LinuxDeviceViewSet
 )
 
 router = NetBoxRouter()
@@ -15,5 +16,6 @@ router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
 router.register("partition", PartitionViewSet)
 router.register("mountedvolume", MountedVolumeViewSet)
+router.register("linuxdevice", LinuxDeviceViewSet)
 
 urlpatterns = router.urls
