@@ -1,8 +1,7 @@
 from django.db.models import Q
 
 from netbox.filtersets import NetBoxModelFilterSet
-
-from netbox_storage.models import MountedVolume, LinuxDevice
+from netbox_storage.models import LinuxDevice
 
 
 class LinuxDeviceFilter(NetBoxModelFilterSet):
