@@ -9,7 +9,7 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
-    StorageConfigurationLinuxVolume, MountedVolume, LinuxDevice
+    StorageConfigurationDrive, MountedVolume, LinuxDevice
 from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
@@ -88,7 +88,7 @@ class LVMSimpleForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = StorageConfigurationLinuxVolume
+        model = StorageConfigurationDrive
         exclude = (
             "cluster_type",
             "vg_name",
@@ -128,7 +128,7 @@ class LVMSimpleForm(NetBoxModelForm):
         print(physicalvolume)
         print(logicalvolume)
 
-        return drive
+        return storage_configuration
 
 
 class LinuxVolumeSimpleForm(NetBoxModelForm):
@@ -191,7 +191,7 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = StorageConfigurationLinuxVolume
+        model = StorageConfigurationDrive
         fields = [
             "virtual_machine",
         ]
